"use client";
import { zodResolver } from "@hookform/resolvers/zod";
import { useForm } from "react-hook-form";
import { z } from "zod";
import { Button } from "../../../components/ui/button";
import { Form, } from "../../../components/ui/form";
import { toast } from "../../../components/ui/use-toast";
import { FormProvider, FuzTextField, FuzSelect, FuzAutoComplete } from "../../../components/hook-form";
var language = [
    { label: "English", value: "en" },
    { label: "French", value: "fr" },
    { label: "German", value: "de" },
    { label: "Spanish", value: "es" },
    { label: "Portuguese", value: "pt" },
    { label: "Russian", value: "ru" },
    { label: "Japanese", value: "ja" },
    { label: "Korean", value: "ko" },
    { label: "Chinese", value: "zh" },
];
var profileFormSchema = z.object({
    username: z
        .string()
        .min(2, {
        message: "Username must be at least 2 characters.",
    })
        .max(30, {
        message: "Username must not be longer than 30 characters.",
    }),
    email: z
        .string({
        required_error: "Please select an email to display.",
    })
        .email(),
    language: z.string({
        required_error: "Please select a language.",
    }),
    // bio: z.string().max(160).min(4),
    // urls: z
    //   .array(
    //     z.object({
    //       value: z.string().url({ message: "Please enter a valid URL." }),
    //     })
    //   )
    //   .optional(),
});
// This can come from your database or API.
var defaultValues = {
// bio: "I own a computer.",
// urls: [
//   { value: "https://shadcn.com" },
//   { value: "http://twitter.com/shadcn" },
// ],
};
export default function ProfileForm() {
    var form = useForm({
        resolver: zodResolver(profileFormSchema),
        defaultValues: defaultValues,
        mode: "onChange",
    });
    // const { fields, append } = useFieldArray({
    //   name: "urls",
    //   control: form.control,
    // })
    function onSubmit(data) {
        toast({
            title: "You submitted the following values:",
            description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
          <code className="text-white">{JSON.stringify(data, null, 2)}</code>
        </pre>),
        });
    }
    return (<Form {...form}>
      <FormProvider onSubmit={form.handleSubmit(onSubmit)} className="space-y-8">
        <FuzTextField name="username" // Pass the name for the field
     description="Used for login credentials" // Pass the description for the field
     form={form} label={""} type={""} placeholder={""}/>
        <FuzSelect name="email" // Pass the name for the field
     options={[{ value: "1@gmail.com", label: "1@gmail.com" }, { value: "2@gmail.com", label: "2@gmail.com" }]} form={form}/>

        <FuzAutoComplete name="language" // Pass the name for the field
     options={language} // Convert the 'languages' array to a mutable arra // Pass the description for the field
     form={form} label={""} placeholder={""}/>
        <Button type="submit">Update profile</Button>
      </FormProvider>
    </Form>);
}
