"use client";
import * as React from "react";
import { flexRender, getCoreRowModel, getFacetedRowModel, getFacetedUniqueValues, getFilteredRowModel, getPaginationRowModel, getSortedRowModel, useReactTable, } from "@tanstack/react-table";
import { Table, TableBody, TableCell, TableHead, TableHeader, TableRow, } from "../../../../components/ui/table";
import { DataTablePagination } from "./data-table-pagination";
import { DataTableToolbar } from "./data-table-toolbar";
import { Skeleton } from "../../../../components/ui/skeleton";
export function DataTable(_a) {
    var _b;
    var columns = _a.columns, data = _a.data, isLoading = _a.isLoading, onRefresh = _a.onRefresh, supabase = _a.supabase;
    var _c = React.useState({}), rowSelection = _c[0], setRowSelection = _c[1];
    var _d = React.useState({}), columnVisibility = _d[0], setColumnVisibility = _d[1];
    var _e = React.useState([]), columnFilters = _e[0], setColumnFilters = _e[1];
    var _f = React.useState([]), sorting = _f[0], setSorting = _f[1];
    var pageSizeArray = [10, 20, 30, 50, 100];
    var table = useReactTable({
        data: data,
        columns: columns,
        state: {
            sorting: sorting,
            columnVisibility: columnVisibility,
            rowSelection: rowSelection,
            columnFilters: columnFilters,
        },
        initialState: { pagination: { pageSize: 10 } },
        enableRowSelection: true,
        onRowSelectionChange: setRowSelection,
        onSortingChange: setSorting,
        onColumnFiltersChange: setColumnFilters,
        onColumnVisibilityChange: setColumnVisibility,
        getCoreRowModel: getCoreRowModel(),
        getFilteredRowModel: getFilteredRowModel(),
        getPaginationRowModel: getPaginationRowModel(),
        getSortedRowModel: getSortedRowModel(),
        getFacetedRowModel: getFacetedRowModel(),
        getFacetedUniqueValues: getFacetedUniqueValues(),
        autoResetPageIndex: true,
    });
    return (<div className="space-y-4">
         <DataTableToolbar table={table} onRefresh={onRefresh} supabase={supabase}/>
      <div className="rounded-md border">
        <Table>
          <TableHeader>
            {table.getHeaderGroups().map(function (headerGroup) { return (<TableRow key={headerGroup.id}>
                {headerGroup.headers.map(function (header) {
                return (<TableHead key={header.id} colSpan={header.colSpan}>
                      {header.isPlaceholder
                        ? null
                        : flexRender(header.column.columnDef.header, header.getContext())}
                    </TableHead>);
            })}
              </TableRow>); })}
          </TableHeader>
          <TableBody>
            {isLoading ? (<>
                {table.getHeaderGroups().map(function (headerGroup) { return (<TableRow key={headerGroup.id}>
                    {headerGroup.headers.map(function (header) {
                    return (<TableCell key={header.id} colSpan={header.colSpan} className="h-6">
                       
                          <Skeleton className="w-[100px] h-[20px] rounded-full"/>
                        </TableCell>);
                })}
                  </TableRow>); })}
                {table.getHeaderGroups().map(function (headerGroup) { return (<TableRow key={headerGroup.id + "-2"}>
                    {headerGroup.headers.map(function (header) {
                    return (<TableCell key={header.id + "-2"} colSpan={header.colSpan} className="h-6">
                          <Skeleton className="w-[100px] h-[20px] rounded-full"/>
                        </TableCell>);
                })}
                  </TableRow>); })}
              </>) : ((_b = table.getRowModel().rows) === null || _b === void 0 ? void 0 : _b.length) ? (table.getRowModel().rows.map(function (row) { return (<TableRow key={row.id} data-state={row.getIsSelected() && "selected"}>
                  {row.getVisibleCells().map(function (cell) { return (<TableCell key={cell.id}>
                      {flexRender(cell.column.columnDef.cell, cell.getContext())}
                    </TableCell>); })}
                </TableRow>); })) : (<TableRow>
                <TableCell colSpan={columns.length} className="h-24 text-center">
                <Skeleton className="w-[100px] h-[20px] rounded-full"/>
                </TableCell>
              </TableRow>)}
          </TableBody>
        </Table>
      </div>
      <div className="flex items-center justify-between px-2">
        <div className="flex-1 text-sm text-muted-foreground">
          {table.getFilteredSelectedRowModel().rows.length} of{" "}

    {table.getFilteredRowModel().rows.length} row(s) selected.

        </div>
        <DataTablePagination table={table} pageSizeArray={pageSizeArray}/>

      </div>
    </div>);
}
