"use client";
import { zodResolver } from "@hookform/resolvers/zod";
import { Check, ChevronsUpDown } from "lucide-react";
import { useForm } from "react-hook-form";
import { z } from "zod";
import { cn } from "../../lib/utils";
import { Button } from "../../components/ui/button";
import { Command, CommandEmpty, CommandGroup, CommandInput, CommandItem, } from "../../components/ui/command";
import { Form, FormControl, FormDescription, FormField, FormItem, FormLabel, FormMessage, } from "../../components/ui/form";
import { Popover, PopoverContent, PopoverTrigger, } from "../../components/ui/popover";
import { toast } from "../../components/ui/use-toast";
var languages = [
    { label: "English", value: "en" },
    { label: "French", value: "fr" },
    { label: "German", value: "de" },
    { label: "Spanish", value: "es" },
    { label: "Portuguese", value: "pt" },
    { label: "Russian", value: "ru" },
    { label: "Japanese", value: "ja" },
    { label: "Korean", value: "ko" },
    { label: "Chinese", value: "zh" },
];
var FormSchema = z.object({
    language: z.string({
        required_error: "Please select a language.",
    }),
});
export function ComboboxForm() {
    var form = useForm({
        resolver: zodResolver(FormSchema),
    });
    function onSubmit(data) {
        toast({
            title: "You submitted the following values:",
            description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
          <code className="text-white">{JSON.stringify(data, null, 2)}</code>
        </pre>),
        });
    }
    return (<Form {...form}>
      <form onSubmit={form.handleSubmit(onSubmit)} className="space-y-6">
        <FormField control={form.control} name="language" render={function (_a) {
            var _b;
            var field = _a.field;
            return (<FormItem className="flex flex-col">
              <FormLabel>Language</FormLabel>
              <Popover>
                <PopoverTrigger asChild>
                  <FormControl>
                    <Button variant="outline" role="combobox" className={cn("w-[200px] justify-between", !field.value && "text-muted-foreground")}>
                      {field.value
                    ? (_b = languages.find(function (language) { return language.value === field.value; })) === null || _b === void 0 ? void 0 : _b.label
                    : "Select language"}
                      <ChevronsUpDown className="ml-2 h-4 w-4 shrink-0 opacity-50"/>
                    </Button>
                  </FormControl>
                </PopoverTrigger>
                <PopoverContent className="w-[200px] p-0">
                  <Command>
                    <CommandInput placeholder="Search language..."/>
                    <CommandEmpty>No language found.</CommandEmpty>
                    <CommandGroup>
                      {languages.map(function (language) { return (<CommandItem value={language.label} key={language.value} onSelect={function () {
                        form.setValue("language", language.value);
                    }}>
                          <Check className={cn("mr-2 h-4 w-4", language.value === field.value
                        ? "opacity-100"
                        : "opacity-0")}/>
                          {language.label}
                        </CommandItem>); })}
                    </CommandGroup>
                  </Command>
                </PopoverContent>
              </Popover>
              <FormDescription>
                This is the language that will be used in the dashboard.
              </FormDescription>
              <FormMessage />
            </FormItem>);
        }}/>
        <Button type="submit">Submit</Button>
      </form>
    </Form>);
}
