import { forwardRef, useEffect } from "react";
import { DatePicker } from "antd";
import { useFormContext } from "react-hook-form";
import dayjs from "dayjs";
import moment from "moment";
var DateWithTime = forwardRef(function (_a) {
    var dateFieldName = _a.dateFieldName, defaultValue = _a.defaultValue, minDate = _a.minDate, maxDate = _a.maxDate, minTime = _a.minTime, maxTime = _a.maxTime;
    var setValue = useFormContext().setValue;
    useEffect(function () {
        setValue(dateFieldName, defaultValue[dateFieldName]);
    }, [defaultValue, setValue, dateFieldName]);
    var handleDateWithChange = function (_date, dateString) {
        var formattedDateString = Array.isArray(dateString) ? dateString.join(', ') : dateString;
        setValue(dateFieldName, formattedDateString);
    };
    var defaultOpenValue = defaultValue && dateFieldName
        ? dayjs(moment(defaultValue[dateFieldName], 'YYYY-MM-DD HH:mm:ss').toDate())
        : dayjs(); // This will set the current date and time
    var minimumTime = moment(minTime, 'h:mm A');
    var maximumTime = moment(maxTime, 'h:mm A');
    var disabledHours = function () {
        var hours = []; // Explicitly type the array as number[]
        var minHour = Number(minimumTime.hour());
        var maxHour = Number(maximumTime.hour());
        for (var i = 0; i < 24; i++) {
            if (i < minHour || i > maxHour) {
                hours.push(i);
            }
        }
        return hours;
    };
    var disabledMinutes = function (selectedHour) {
        if (selectedHour === minimumTime.hour()) {
            var minutes = []; // Explicitly type the array as number[]
            for (var i = 0; i < 60; i++) {
                if (i < minimumTime.minute()) {
                    minutes.push(i);
                }
            }
            return minutes;
        }
        else if (selectedHour === maximumTime.hour()) {
            var minutes = []; // Explicitly type the array as number[]
            for (var i = 0; i < 60; i++) {
                if (i > maximumTime.minute()) {
                    minutes.push(i);
                }
            }
            return minutes;
        }
        return [];
    };
    var disabledSeconds = function (selectedHour, selectedMinute) {
        var seconds = []; // Explicitly type the array as number[]
        var minSecond = Number(minimumTime.second());
        var maxSecond = Number(maximumTime.second());
        if (selectedHour === minimumTime.hour() && selectedMinute === minimumTime.minute()) {
            for (var i = 0; i < 60; i++) {
                if (i < minSecond) {
                    seconds.push(i);
                }
            }
        }
        else if (selectedHour === maximumTime.hour() && selectedMinute === maximumTime.minute()) {
            for (var i = 0; i < 60; i++) {
                if (i > maxSecond) {
                    seconds.push(i);
                }
            }
        }
        return seconds;
    };
    return (<DatePicker showTime onChange={handleDateWithChange} defaultValue={defaultOpenValue} allowClear={false} disabledDate={function (current) {
            return !!current && ((!!minDate && current.isBefore(dayjs(minDate), "day")) ||
                (!!maxDate && current.isAfter(dayjs(maxDate), "day")));
        }} disabledHours={disabledHours} disabledMinutes={disabledMinutes} disabledSeconds={disabledSeconds}/>);
});
DateWithTime.displayName = "DateWithTime";
export default DateWithTime;
