import React, { useState } from 'react';
import { useFormContext } from 'react-hook-form';
import { Stack, DateRangePicker } from 'rsuite';
import moment from 'moment'; // Import moment library for date handling
import 'rsuite/dist/rsuite.css';
import { isBefore, isAfter } from 'date-fns';
import { TimePicker } from 'antd';
import dayjs from 'dayjs'; // Import dayjs library
import DateWithTime from './dateWithTime';
import TimeRange from './timeRange';
import { DatePicker, } from 'rsuite';
var Datepicker = function (props) {
    var dateFieldName = props.dateFieldName, picker = props.picker, defaultValue = props.defaultValue, maxDate = props.maxDate, minDate = props.minDate, minTime = props.minTime, maxTime = props.maxTime;
    var setValue = useFormContext().setValue;
    console.log("defaultValue", defaultValue);
    var selectedDefaultValue = defaultValue;
    var DateRangeStart = defaultValue;
    var startDate = DateRangeStart ? moment(DateRangeStart.startDate).toDate() : new Date();
    var endDate = DateRangeStart ? moment(DateRangeStart.endDate).toDate() : new Date();
    var selectedDate = useState(selectedDefaultValue ? moment(selectedDefaultValue).toDate() : new Date())[0];
    var handleDateChange = function (date) {
        var formattedDate = date ? moment(date).format('YYYY-MM-DD') : '';
        setValue(dateFieldName, formattedDate);
    };
    var handleTimeChange = function (date, dateString) {
        if (date && typeof dateString === 'string') {
            var indianTime = date.format('HH:mm:ss');
            setValue(dateFieldName, indianTime);
        }
    };
    var handleDateRangeChange = function (dateRange) {
        var startDate = dateRange ? moment(dateRange[0]).format('YYYY-MM-DD') : '';
        var endDate = dateRange ? moment(dateRange[1]).format('YYYY-MM-DD') : '';
        setValue(dateFieldName, { startDate: startDate, endDate: endDate });
    };
    var minimumDate = new Date(minDate);
    var maximumDate = new Date(maxDate);
    var minimumTime = moment(minTime, 'h:mm A');
    var maximumTime = moment(maxTime, 'h:mm A');
    var disabledHours = function () {
        var hours = []; // Explicitly type the array as number[]
        var minHour = Number(minimumTime.hour());
        var maxHour = Number(maximumTime.hour());
        for (var i = 0; i < 24; i++) {
            if (i < minHour || i > maxHour) {
                hours.push(i);
            }
        }
        return hours;
    };
    var disabledMinutes = function (selectedHour) {
        if (selectedHour === minimumTime.hour()) {
            var minutes = []; // Explicitly type the array as number[]
            for (var i = 0; i < 60; i++) {
                if (i < minimumTime.minute()) {
                    minutes.push(i);
                }
            }
            return minutes;
        }
        else if (selectedHour === maximumTime.hour()) {
            var minutes = []; // Explicitly type the array as number[]
            for (var i = 0; i < 60; i++) {
                if (i > maximumTime.minute()) {
                    minutes.push(i);
                }
            }
            return minutes;
        }
        return [];
    };
    var disabledSeconds = function (selectedHour, selectedMinute) {
        var seconds = []; // Explicitly type the array as number[]
        if (selectedHour === minimumTime.hour() && selectedMinute === minimumTime.minute()) {
            for (var i = 0; i < 60; i++) {
                if (i < minimumTime.second()) {
                    seconds.push(i);
                }
            }
            return seconds;
        }
        else if (selectedHour === maximumTime.hour() && selectedMinute === maximumTime.minute()) {
            for (var i = 0; i < 60; i++) {
                if (i > maximumTime.second()) {
                    seconds.push(i);
                }
            }
            return seconds;
        }
        return [];
    };
    var maxTimeParts = maxTime ? maxTime.split(/[.: ]/) : "";
    var hours = parseInt(maxTimeParts[0]);
    var maxTimeminutes = parseInt(maxTimeParts[1]);
    if (maxTimeParts[2] === "PM" && hours !== 12) {
        hours += 12;
    }
    console.log("Minutes1:", maxTimeminutes);
    var minTimeParts = minTime ? minTime.split(/[.: ]/) : "";
    var hours = parseInt(minTimeParts[0]);
    var minTimeminutes = parseInt(minTimeParts[1]);
    if (minTimeParts[2] === "PM" && hours !== 12) {
        hours += 12;
    }
    console.log("Minutes2:", minTimeminutes);
    var defaultOpenValue = dayjs(moment(defaultValue, 'HH:mm:ss').toDate());
    return (<React.Fragment>
      <Stack direction="column" style={{ display: 'block' }}>
        {(function () {
            switch (picker) {
                case 'date':
                    return (<DatePicker style={{ width: "100%" }} shouldDisableDate={function (date) { return isBefore(date, minimumDate) || isAfter(date, maximumDate); }} defaultValue={selectedDate} onChange={handleDateChange} format="yyyy-MM-dd"/>);
                case 'dateRange':
                    return <DateRangePicker style={{ width: "100%" }} onChange={handleDateRangeChange} defaultValue={[startDate, endDate]} shouldDisableDate={function (date) { return isBefore(date, minimumDate) || isAfter(date, maximumDate); }}/>;
                case 'timeRange':
                    return (<TimeRange minTime={minTime} maxTime={maxTime} dateFieldName={dateFieldName} defaultValue={defaultValue}/>);
                case 'dateWithTime':
                    return (<DateWithTime minTime={minTime} maxTime={maxTime} maxDate={maxDate} minDate={minDate} dateFieldName={dateFieldName} defaultValue={defaultValue}/>);
                default:
                    return (<TimePicker onChange={handleTimeChange} defaultValue={defaultOpenValue} disabledHours={disabledHours} disabledMinutes={disabledMinutes} disabledSeconds={disabledSeconds}/>);
            }
        })()}
      </Stack>
    </React.Fragment>);
};
export { Datepicker };
