import { createStitches, createTheme } from '@stitches/core';
import { merge, VIEWS, en } from 'pasubot-auth-ui-shared';
import { useEffect, useState } from 'react';
import { EmailAuth, ForgottenPassword, MagicLink, SocialAuth, UpdatePassword, VerifyOtp, } from './interfaces';
import { UserContextProvider, useUser } from './UserContext';
function Auth(_a) {
    /**
     * Localization support
     */
    var _b;
    var supabaseClient = _a.supabaseClient, _c = _a.socialLayout, socialLayout = _c === void 0 ? 'vertical' : _c, providers = _a.providers, providerScopes = _a.providerScopes, queryParams = _a.queryParams, _d = _a.view, view = _d === void 0 ? 'sign_in' : _d, redirectTo = _a.redirectTo, _e = _a.onlyThirdPartyProviders, onlyThirdPartyProviders = _e === void 0 ? false : _e, _f = _a.magicLink, magicLink = _f === void 0 ? false : _f, _g = _a.showLinks, showLinks = _g === void 0 ? true : _g, appearance = _a.appearance, _h = _a.theme, theme = _h === void 0 ? 'default' : _h, _j = _a.localization, localization = _j === void 0 ? { variables: {} } : _j, _k = _a.otpType, otpType = _k === void 0 ? 'email' : _k, additionalData = _a.additionalData, passwordLimit = _a.passwordLimit, children = _a.children;
    var i18n = merge(en, (_b = localization.variables) !== null && _b !== void 0 ? _b : {});
    var _l = useState(view), authView = _l[0], setAuthView = _l[1];
    var _m = useState(''), defaultEmail = _m[0], setDefaultEmail = _m[1];
    var _o = useState(''), defaultPassword = _o[0], setDefaultPassword = _o[1];
    /**
     * Simple boolean to detect if authView 'sign_in' or 'sign_up' or 'magic_link' is used
     *
     * @returns boolean
     */
    var SignView = authView === 'sign_in' ||
        authView === 'sign_up' ||
        authView === 'magic_link';
    useEffect(function () {
        var _a, _b, _c, _d;
        createStitches({
            theme: merge((_b = (_a = appearance === null || appearance === void 0 ? void 0 : appearance.theme) === null || _a === void 0 ? void 0 : _a.default) !== null && _b !== void 0 ? _b : {}, (_d = (_c = appearance === null || appearance === void 0 ? void 0 : appearance.variables) === null || _c === void 0 ? void 0 : _c.default) !== null && _d !== void 0 ? _d : {}),
        });
    }, [appearance]);
    /**
     * Wraps around all auth components
     * renders the social auth providers if SignView is true
     *
     * also handles the theme override
     *
     * @param children
     * @returns React.ReactNode
     */
    var Container = function (_a) {
        var _b, _c;
        var children = _a.children;
        return (
        // @ts-ignore
        <div className={theme !== 'default'
                ? createTheme(merge(
                // @ts-ignore
                appearance === null || appearance === void 0 ? void 0 : appearance.theme[theme], (_c = (_b = appearance === null || appearance === void 0 ? void 0 : appearance.variables) === null || _b === void 0 ? void 0 : _b[theme]) !== null && _c !== void 0 ? _c : {}))
                : ''}>
      {SignView && (<SocialAuth appearance={appearance} supabaseClient={supabaseClient} providers={providers} providerScopes={providerScopes} queryParams={queryParams} socialLayout={socialLayout} redirectTo={redirectTo} onlyThirdPartyProviders={onlyThirdPartyProviders} i18n={i18n} view={authView}/>)}
      {!onlyThirdPartyProviders && children}
    </div>);
    };
    useEffect(function () {
        /**
         * Overrides the authview if it is changed externally
         */
        var authListener = supabaseClient.auth.onAuthStateChange(function (event) {
            if (event === 'PASSWORD_RECOVERY') {
                setAuthView('update_password');
            }
            else if (event === 'USER_UPDATED') {
                setAuthView('sign_in');
            }
        }).data;
        setAuthView(view);
        return function () { return authListener.subscription.unsubscribe(); };
    }, [view]);
    var emailProp = {
        supabaseClient: supabaseClient,
        setAuthView: setAuthView,
        defaultEmail: defaultEmail,
        defaultPassword: defaultPassword,
        setDefaultEmail: setDefaultEmail,
        setDefaultPassword: setDefaultPassword,
        redirectTo: redirectTo,
        magicLink: magicLink,
        showLinks: showLinks,
        i18n: i18n,
        appearance: appearance,
        passwordLimit: passwordLimit,
    };
    /**
     * View handler, displays the correct Auth view
     * all views are wrapped in <Container/>
     */
    switch (authView) {
        case VIEWS.SIGN_IN:
            return (<Container>
          <EmailAuth {...emailProp} authView={'sign_in'}/>
        </Container>);
        case VIEWS.SIGN_UP:
            return (<Container>
          <EmailAuth appearance={appearance} supabaseClient={supabaseClient} authView={'sign_up'} setAuthView={setAuthView} defaultEmail={defaultEmail} defaultPassword={defaultPassword} setDefaultEmail={setDefaultEmail} setDefaultPassword={setDefaultPassword} redirectTo={redirectTo} magicLink={magicLink} showLinks={showLinks} i18n={i18n} additionalData={additionalData} passwordLimit={passwordLimit} children={children}/>
        </Container>);
        case VIEWS.FORGOTTEN_PASSWORD:
            return (<Container>
          <ForgottenPassword appearance={appearance} supabaseClient={supabaseClient} setAuthView={setAuthView} redirectTo={redirectTo} showLinks={showLinks} i18n={i18n}/>
        </Container>);
        case VIEWS.MAGIC_LINK:
            return (<Container>
          <MagicLink appearance={appearance} supabaseClient={supabaseClient} setAuthView={setAuthView} redirectTo={redirectTo} showLinks={showLinks} i18n={i18n}/>
        </Container>);
        case VIEWS.UPDATE_PASSWORD:
            return (<UpdatePassword appearance={appearance} supabaseClient={supabaseClient} i18n={i18n} passwordLimit={passwordLimit}/>);
        case VIEWS.VERIFY_OTP:
            return (<VerifyOtp appearance={appearance} supabaseClient={supabaseClient} otpType={otpType} i18n={i18n}/>);
        default:
            return null;
    }
}
// @ts-ignore
Auth.ForgottenPassword = ForgottenPassword;
// @ts-ignore
Auth.UpdatePassword = UpdatePassword;
// @ts-ignore
Auth.MagicLink = MagicLink;
// @ts-ignore
Auth.UserContextProvider = UserContextProvider;
// @ts-ignore
Auth.useUser = useUser;
export default Auth;
